# Slot: prefixes


prefix / URI definitions to be added to the context beyond those fetched from prefixcommons in id_prefixes

URI: [http://w3id.org/biolink/biolinkml/meta/prefixes](slot_uri)
## Domain and Range

[SchemaDefinition](SchemaDefinition.md) -><sub>opt</sub> [[Prefix](Prefix.md)]
## Inheritance

## Children

## Used by

 * [SchemaDefinition](SchemaDefinition.md)
